function [fo]=modeuler(h,old,a,r,b,force)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  Purpose: Apply modified Euler scheme to the Lorenz equations
%
%  (c) 2002  Data Assimilation Research Centre
%
%  Original Fortran program by Marek Wlasak
%  Converted to Matlab by Amos Lawless
%
%  6/7/04 Moved all functions inline to make adjoint easier
%
%  List of main variables
%    a:          sigma coefficient in equations
%    r:          rho coefficient in equations
%    b:          beta coefficient in equations
%    h:          Time step for numerical scheme
%    tstep:      Number of time steps to perform
%    [xval,yval,zval]: Initial fields
%    j:          Index to pick up correct initial field
%
%  Output:
%    [xo,yo,zo]: Trajectories of evolved fields
%
% modified by A. Fowler to include a forcing term
%   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
x(1)=old(1);
y(1)=old(2);
z(1)=old(3);

kx1 = h*a*(y-x);
ky1 = h*(r*x-y-x*z);
kz1 = h*(x*y- b*z);

kx2 = h*a*(y+ky1-x-kx1);
ky2 = h*(r*(x+kx1)-y-ky1-(x+kx1)*(z+kz1));
kz2 = h*((x+kx1)*(y+ky1)-b*(z+kz1));

x=x+0.5d0*(kx1+kx2);
y=y+0.5d0*(ky1+ky2);
z=z+0.5d0*(kz1+kz2);

fo(:,1)=x+ force(1);
fo(:,2)=y+ force(2);
fo(:,3)=z+ force(3);
%

